@@ -25,6 +25,8 @@ if __name__ == '__main__':
     parser.add_argument('--comp', type=int, default=1, help='reducing fps only for video. fps/comp. default 1')
     parser.add_argument('--gamma', type=float, default=-1, help='gamma over 0. default -1(none)')
     parser.add_argument('--b_propo', type=str2bool, default=False, help='black proportion')
+    parser.add_argument('--show', type=str2bool, default=False, help='show images with python imshow')
+    parser.add_argument('--save', type=str2bool, default=False, help='not to save output')
     
     opt = parser.parse_args()
     print(opt)
@@ -38,34 +40,36 @@ if __name__ == '__main__':
 
 def defaultDict():
     default_dict = {}
-    default_dict['--source'] = './example.jpeg'
-    default_dict['--output'] = './output'
-    default_dict['--option'] = 'skl'
-    default_dict['--exclude'] = []
-    default_dict['--proto'] = './pose/coco/pose_deploy_linevec.prototxt'
-    default_dict['--weight'] = './pose/coco/pose_iter_440000.caffemodel'
-    default_dict['--thres'] = 0.1
-    default_dict['--gray'] = False
-    default_dict['--back'] = False
-    default_dict['--selectRect'] = False
-    default_dict['--autolocation'] = False
-    default_dict['--comp'] = 1
-    default_dict['--gamma'] = -1
-    default_dict['--b_propo'] = False
+    default_dict['source'] = './example.jpeg'
+    default_dict['output'] = './output'
+    default_dict['option'] = 'skl'
+    default_dict['exclude'] = []
+    default_dict['proto'] = './pose/coco/pose_deploy_linevec.prototxt'
+    default_dict['weight'] = './pose/coco/pose_iter_440000.caffemodel'
+    default_dict['thres'] = 0.1
+    default_dict['gray'] = False
+    default_dict['back'] = False
+    default_dict['selectRect'] = False
+    default_dict['autolocation'] = False
+    default_dict['comp'] = 1
+    default_dict['gamma'] = -1
+    default_dict['b_propo'] = False
+    default_dict['show'] = False
+    default_dict['save'] = False
     return default_dict
 
 def skprovider(dict_object):
     arg_list = []
     keys = dict_object.keys()
     for key in keys:
-        if key == '--exclude':
+        if key == 'exclude':
             if len(dict_object[key]) == 0:
                 continue
             for item in dict_object[key]:
-                arg_list.append(key)
+                arg_list.append('--' + key)
                 arg_list.append(str(item))
         else:
-            arg_list.append(key)
+            arg_list.append('--' + key)
             arg_list.append(str(dict_object[key]))
 
     parser = argparse.ArgumentParser()
@@ -84,6 +88,8 @@ def skprovider(dict_object):
     parser.add_argument('--comp', type=int, default=1, help='reducing fps only for video. fps/comp. default 1')
     parser.add_argument('--gamma', type=float, default=-1, help='gamma over 0. default -1(none)')
     parser.add_argument('--b_propo', type=str2bool, default=False, help='black proportion')
+    parser.add_argument('--show', type=str2bool, default=False, help='show images with python imshow')
+    parser.add_argument('--save', type=str2bool, default=False, help='not to save output')
 
     opt = parser.parse_args(arg_list)
     print(opt)
